@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Data.Bifoldable
@@ -29,7 +30,7 @@ module Data.Bifoldable
   ) where
 
 import Control.Applicative
-import Data.Monoid
+import Data.Semigroup
 import Data.Tagged
 
 -- | Minimal definition either 'bifoldr' or 'bifoldMap'
@@ -86,6 +87,15 @@ class Bifoldable p where
   bifoldl f g z t = appEndo (getDual (bifoldMap (Dual . Endo . flip f) (Dual . Endo . flip g) t)) z
   {-# INLINE bifoldl #-}
 
+#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 708
+  {-# MINIMAL bifoldr | bifoldMap #-}
+#endif
+
+#if MIN_VERSION_semigroups(0,16,2)
+instance Bifoldable Arg where
+  bifoldMap f g (Arg a b) = f a `mappend` g b
+#endif
+
 instance Bifoldable (,) where
   bifoldMap f g ~(a, b) = f a `mappend` g b
   {-# INLINE bifoldMap #-}
